@@ -14,7 +14,8 @@ from .utils import slicer
 #       and research a bit into this being a reasonable way to convert bytes
 #       into structs (and back).
 # TODO: consider widening support for other encodings (eg: latin1, utf-8, etc)
-#       in file/directory names.       
+#       in file/directory names.
+# TODO: Linux-style LFN support (see https://lkml.org/lkml/2009/6/26/314)     
 
 
 ATTRIBUTES = {
@@ -90,8 +91,6 @@ def read_time(bytes_, mili=0):
     minute = min(59, minute)
     second = min(59, second)
     # that gives a few sanity checks and should catch that particular issue
-    #     note: we're still not checking the day/month correctly, we should
-    #           be using the calendar module for that
     dt = datetime.datetime(year, month, day, hour, minute, second, micros)
     return dt
 
@@ -229,14 +228,13 @@ class FileRecord:
         The flags of the File Record. Read only.
 
         This is actually a reserved field, which non-Microsoft implementations
-        use for different purposes. Other than read it, we don't do anything
-        with it.
+        use for different purposes.
         """
         return self._flags
     
     @flags.setter
     def flags(self, value):
-        pass  # let's keep this read-only for the moment
+        self._flags = value  # we're gonna need this for the optional arguments
 
     @property
     def cluster(self):
@@ -377,6 +375,9 @@ class FileRecord:
             if self._name[0:1] == b"\xe5":
                 self._name = b"_" + self._name[1:]
     
+    def __bytes__(self):
+        return b""
+    
     def __repr__(self):
         name = self.name.decode("latin1")
         ext  = self.ext.decode("latin1")
@@ -727,6 +728,20 @@ class FAT32:
         raw_fat = self._handle.read(spf * bps)
         self.fat2 = [ v[0] for v in struct.iter_unpack("<L", raw_fat) ]
     
+    def _cluster_address(self, cluster):
+        """
+        Calculates `cluster` address in the file the filesystem is being read
+        from.
+
+        :param cluster: cluster number to get the address of
+        :return: offset in base file at which the cluster starts
+        """
+        cluster -= 2
+        bps = self.bytes_per_sector
+        spc = self.sectors_per_cluster
+        bca = self.base_cluster_address
+        return bca + (cluster * spc * bps)
+    
     def _read_cluster(self, cluster, nclusters=1):
         """
         Reads `nclusters` (defaults to 1) from the filesystem, starting at
